==> mofed-modules-24.07_24.07.0.6.1.0+ds1.orig.tar.xz: mofed-modules-24.07-24.07.0.6.1.0+ds1/mlnx-ofed-kernel/drivers/infiniband/hw/mlx4/main.c <==
/*
 * Copyright (c) 2020 Mellanox Technologies. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <linux/module.h>
#include <linux/init.h>
#include <linux/errno.h>

#define DRV_NAME	mlx4_ib
#define DRV_VERSION	"24.07-0.6.1"
#define DRV_RELDATE	"11 Aug 2024"

MODULE_AUTHOR("Tzafrir Cohen");
MODULE_LICENSE("Dual BSD/GPL");
#ifdef RETPOLINE_MLNX
MODULE_INFO(retpoline, "Y");
#endif
MODULE_VERSION(DRV_VERSION);

#define dummy_module_code(name) \
MODULE_DESCRIPTION(#name " dummy kernel module"); \
\
static int __init name##_init(void) \
{ \
	return 0; \
} \
\
static void __exit name##_cleanup(void) \
{ \
} \
\
module_init(name##_init); \
module_exit(name##_cleanup); \

dummy_module_code(DRV_NAME);

==> mofed-modules-24.10_24.10.0.7.0.0+ds1.orig.tar.xz: mofed-modules-24.10-24.10.0.7.0.0+ds1/mlnx-ofed-kernel/drivers/infiniband/hw/mlx4/main.c <==
/*
 * Copyright (c) 2020 Mellanox Technologies. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <linux/module.h>
#include <linux/init.h>
#include <linux/errno.h>

#define DRV_NAME	mlx4_ib
#define DRV_VERSION	"24.10-0.7.0"
#define DRV_RELDATE	"08 Nov 2024"

MODULE_AUTHOR("Tzafrir Cohen");
MODULE_LICENSE("Dual BSD/GPL");
#ifdef RETPOLINE_MLNX
MODULE_INFO(retpoline, "Y");
#endif
MODULE_VERSION(DRV_VERSION);

#define dummy_module_code(name) \
MODULE_DESCRIPTION(#name " dummy kernel module"); \
\
static int __init name##_init(void) \
{ \
	return 0; \
} \
\
static void __exit name##_cleanup(void) \
{ \
} \
\
module_init(name##_init); \
module_exit(name##_cleanup); \

dummy_module_code(DRV_NAME);
